@@ -1,18 +1,19 @@
 #include <cdk_int.h>
+#include <scroller.h>
 
 /*
  * $Author: tom $
- * $Date: 2005/12/30 00:29:34 $
- * $Revision: 1.143 $
+ * $Date: 2014/11/06 00:29:59 $
+ * $Revision: 1.155 $
  */
 
 /*
  * Declare file local prototypes.
  */
-static int createList(CDKSELECTION *selection, char **list, int listSize);
+static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize);
 static void drawCDKSelectionList (CDKSELECTION *selection, boolean Box);
-static void setViewSize(CDKSELECTION *scrollp, int listSize);
-static int maxViewSize(CDKSELECTION *scrollp);
+static void setViewSize (CDKSELECTION *scrollp, int listSize);
+static int maxViewSize (CDKSELECTION *scrollp);
 
 /* Determine how many characters we can shift to the right */
 /* before all the items have been scrolled off the screen. */
@@ -23,69 +24,84 @@ static int maxViewSize(CDKSELECTION *scrollp);
 			      : (widest - AvailableWidth(w)))
 #define WidestItem(w)      ((w)->maxLeftChar + AvailableWidth(w))
 
-#define SCREENPOS(w,n) (w)->itemPos[n] - (w)->leftChar + scrollbarAdj /* + BorderOf(w) */
+#define SCREENPOS(w,n) (w)->itemPos[n] - (w)->leftChar + scrollbarAdj	/* + BorderOf(w) */
 
-DeclareCDKObjects(SELECTION, Selection, setCdk, Int);
+DeclareCDKObjects (SELECTION, Selection, setCdk, Int);
 
 /*
  * This function creates a selection widget.
  */
-CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int splace, int height, int width, char *title, char **list, int listSize, char **choices, int choiceCount, chtype highlight, boolean Box, boolean shadow)
+CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen,
+			       int xplace,
+			       int yplace,
+			       int splace,
+			       int height,
+			       int width,
+			       const char *title,
+			       CDK_CSTRING2 list,
+			       int listSize,
+			       CDK_CSTRING2 choices,
+			       int choiceCount,
+			       chtype highlight,
+			       boolean Box,
+			       boolean shadow)
 {
-   CDKSELECTION *selection	= 0;
-   int widestItem		= -1;
-   int parentWidth		= getmaxx(cdkscreen->window);
-   int parentHeight		= getmaxy(cdkscreen->window);
-   int boxWidth			= width;
-   int boxHeight		= height;
-   int xpos			= xplace;
-   int ypos			= yplace;
-   int j			= 0;
+   /* *INDENT-EQLS* */
+   CDKSELECTION *selection      = 0;
+   int widestItem               = -1;
+   int parentWidth              = getmaxx (cdkscreen->window);
+   int parentHeight             = getmaxy (cdkscreen->window);
+   int boxWidth;
+   int boxHeight;
+   int xpos                     = xplace;
+   int ypos                     = yplace;
+   int j                        = 0;
    int junk2;
-
+   /* *INDENT-OFF* */
    static const struct { int from; int to; } bindings[] = {
-	     	{ CDK_BACKCHAR,	KEY_PPAGE },
-	     	{ CDK_FORCHAR,	KEY_NPAGE },
+		{ CDK_BACKCHAR, KEY_PPAGE },
+		{ CDK_FORCHAR,	KEY_NPAGE },
 		{ 'g',		KEY_HOME },
 		{ '1',		KEY_HOME },
 		{ 'G',		KEY_END },
 		{ '<',		KEY_HOME },
 		{ '>',		KEY_END },
    };
+   /* *INDENT-ON* */
 
    if (choiceCount <= 0
-    || (selection = newCDKObject(CDKSELECTION, &my_funcs)) == 0
-    || (selection->choice    = typeCallocN(chtype *, choiceCount + 1)) == 0
-    || (selection->choicelen = typeCallocN(int,      choiceCount + 1)) == 0)
+       || (selection = newCDKObject (CDKSELECTION, &my_funcs)) == 0
+       || (selection->choice = typeCallocN (chtype *, choiceCount + 1)) == 0
+       || (selection->choicelen = typeCallocN (int, choiceCount + 1)) == 0)
    {
-      destroyCDKObject(selection);
+      destroyCDKObject (selection);
       return (0);
    }
 
    setCDKSelectionBox (selection, Box);
 
-  /*
-   * If the height is a negative value, the height will
-   * be ROWS-height, otherwise, the height will be the
-   * given height.
-   */
+   /*
+    * If the height is a negative value, the height will
+    * be ROWS-height, otherwise, the height will be the
+    * given height.
+    */
    boxHeight = setWidgetDimension (parentHeight, height, 0);
 
-  /*
-   * If the width is a negative value, the width will
-   * be COLS-width, otherwise, the width will be the
-   * given width.
-   */
+   /*
+    * If the width is a negative value, the width will
+    * be COLS-width, otherwise, the width will be the
+    * given width.
+    */
    boxWidth = setWidgetDimension (parentWidth, width, 0);
 
-   boxWidth = setCdkTitle(ObjOf(selection), title, boxWidth);
+   boxWidth = setCdkTitle (ObjOf (selection), title, boxWidth);
 
    /* Set the box height. */
-   if (TitleLinesOf(selection) > boxHeight)
+   if (TitleLinesOf (selection) > boxHeight)
    {
-      boxHeight = TitleLinesOf(selection)
-      		+ MINIMUM(listSize, 8)
-		+ 2 * BorderOf(selection);
+      boxHeight = TitleLinesOf (selection)
+	 + MINIMUM (listSize, 8)
+	 + 2 * BorderOf (selection);
    }
 
    selection->maxchoicelen = 0;
@@ -101,13 +117,13 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int
       selection->scrollbar = FALSE;
    }
 
-  /*
-   * Make sure we didn't extend beyond the dimensions of the window.
-   */
+   /*
+    * Make sure we didn't extend beyond the dimensions of the window.
+    */
    selection->boxWidth = (boxWidth > parentWidth ? parentWidth : boxWidth);
    selection->boxHeight = (boxHeight > parentHeight ? parentHeight : boxHeight);
 
-   setViewSize(selection, listSize);
+   setViewSize (selection, listSize);
 
    /* Rejustify the x and y positions if we need to. */
    alignxy (cdkscreen->window, &xpos, &ypos, selection->boxWidth, selection->boxHeight);
@@ -118,7 +134,7 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int
    /* Is the window null?? */
    if (selection->win == 0)
    {
-      destroyCDKObject(selection);
+      destroyCDKObject (selection);
       return (0);
    }
 
@@ -129,53 +145,59 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int
    if (splace == RIGHT)
    {
       selection->scrollbarWin = subwin (selection->win,
-					maxViewSize(selection), 1,
-					SCREEN_YPOS(selection, ypos),
-					xpos + selection->boxWidth - BorderOf(selection) - 1);
+					maxViewSize (selection), 1,
+					SCREEN_YPOS (selection, ypos),
+					(xpos
+					 + selection->boxWidth
+					 - BorderOf (selection)
+					 - 1));
    }
    else if (splace == LEFT)
    {
       selection->scrollbarWin = subwin (selection->win,
-					maxViewSize(selection), 1,
-					SCREEN_YPOS(selection, ypos),
-					SCREEN_XPOS(selection, xpos));
+					maxViewSize (selection), 1,
+					SCREEN_YPOS (selection, ypos),
+					SCREEN_XPOS (selection, xpos));
    }
    else
    {
       selection->scrollbarWin = 0;
    }
 
-   /* Set the rest of the variables */
-   ScreenOf(selection)			= cdkscreen;
-   selection->parent			= cdkscreen->window;
-   selection->scrollbarPlacement	= splace;
-   selection->maxLeftChar		= 0;
-   selection->leftChar			= 0;
-   selection->highlight			= highlight;
-   selection->choiceCount		= choiceCount;
-   initExitType(selection);
-   ObjOf(selection)->acceptsFocus	= TRUE;
-   ObjOf(selection)->inputWindow	= selection->win;
-   selection->shadow			= shadow;
+   /* *INDENT-EQLS* Set the rest of the variables */
+   ScreenOf (selection)                 = cdkscreen;
+   selection->parent                    = cdkscreen->window;
+   selection->scrollbarPlacement        = splace;
+   selection->maxLeftChar               = 0;
+   selection->leftChar                  = 0;
+   selection->highlight                 = highlight;
+   selection->choiceCount               = choiceCount;
+   initExitType (selection);
+   ObjOf (selection)->acceptsFocus      = TRUE;
+   ObjOf (selection)->inputWindow       = selection->win;
+   selection->shadow                    = shadow;
 
    setCDKSelectionCurrent (selection, 0);
 
    /* Each choice has to be converted from char * to chtype * */
    for (j = 0; j < choiceCount; j++)
    {
-      selection->choice[j]	= char2Chtype (choices[j], &selection->choicelen[j], &junk2);
-      selection->maxchoicelen	= MAXIMUM (selection->maxchoicelen, selection->choicelen[j]);
+      selection->choice[j] = char2Chtype (choices[j],
+					  &selection->choicelen[j],
+					  &junk2);
+      selection->maxchoicelen = MAXIMUM (selection->maxchoicelen,
+					 selection->choicelen[j]);
    }
 
    /* Each item in the needs to be converted to chtype * */
-   widestItem = createList(selection, list, listSize);
+   widestItem = createList (selection, list, listSize);
    if (widestItem > 0)
    {
-      updateViewWidth(selection, widestItem);
+      updateViewWidth (selection, widestItem);
    }
    else if (listSize)
    {
-      destroyCDKObject(selection);
+      destroyCDKObject (selection);
       return (0);
    }
 
@@ -186,8 +208,12 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int
    }
 
    /* Setup the key bindings. */
-   for (j = 0; j < (int) SIZEOF(bindings); ++j)
-      bindCDKObject (vSELECTION, selection, bindings[j].from, getcCDKBind, (void *)(long)bindings[j].to);
+   for (j = 0; j < (int)SIZEOF (bindings); ++j)
+      bindCDKObject (vSELECTION,
+		     selection,
+		     (chtype)bindings[j].from,
+		     getcCDKBind,
+		     (void *)(long)bindings[j].to);
 
    /* Register this baby. */
    registerCDKObject (cdkscreen, vSELECTION, selection);
@@ -201,12 +227,7 @@ CDKSELECTION *newCDKSelection (CDKSCREEN *cdkscreen, int xplace, int yplace, int
  */
 static void fixCursorPosition (CDKSELECTION *selection)
 {
-   int scrollbarAdj = (selection->scrollbarPlacement == LEFT) ?  1 :  0;
-   int ypos = SCREEN_YPOS(selection, selection->currentItem - selection->currentTop);
-   int xpos = SCREEN_XPOS(selection, 0) + scrollbarAdj;
-
-   wmove(InputWindowOf(selection), ypos, xpos);
-   wrefresh(InputWindowOf(selection));
+   scroller_FixCursorPosition ((CDKSCROLLER *)selection);
 }
 
 /*
@@ -215,7 +236,7 @@ static void fixCursorPosition (CDKSELECTION *selection)
 int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
 {
    /* Draw the selection list */
-   drawCDKSelection (selection, ObjOf(selection)->box);
+   drawCDKSelection (selection, ObjOf (selection)->box);
 
    if (actions == 0)
    {
@@ -226,7 +247,7 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
       for (;;)
       {
 	 fixCursorPosition (selection);
-	 input = getchCDKObject (ObjOf(selection), &functionKey);
+	 input = (chtype)getchCDKObject (ObjOf (selection), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKSelection (selection, input);
@@ -254,7 +275,7 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
    }
 
    /* Set the exit type and return. */
-   setExitType(selection, 0);
+   setExitType (selection, 0);
    return 0;
 }
 
@@ -264,128 +285,143 @@ int activateCDKSelection (CDKSELECTION *selection, chtype *actions)
 static int _injectCDKSelection (CDKOBJS *object, chtype input)
 {
    CDKSELECTION *selection = (CDKSELECTION *)object;
+   CDKSCROLLER *widget = (CDKSCROLLER *)object;
    int ppReturn = 1;
    int ret = unknownInt;
    bool complete = FALSE;
 
    /* Set the exit type. */
-   setExitType(selection, 0);
+   setExitType (widget, 0);
 
-   /* Draw the selection list */
-   drawCDKSelectionList (selection, ObjOf(selection)->box);
+   /* Draw the widget list */
+   drawCDKSelectionList (selection, ObjOf (widget)->box);
 
    /* Check if there is a pre-process function to be called. */
-   if (PreProcessFuncOf(selection) != 0)
+   if (PreProcessFuncOf (widget) != 0)
    {
       /* Call the pre-process function. */
-      ppReturn = PreProcessFuncOf(selection) (vSELECTION, selection, PreProcessDataOf(selection), input);
+      ppReturn = PreProcessFuncOf (widget) (vSELECTION,
+					    widget,
+					    PreProcessDataOf (widget),
+					    input);
    }
 
    /* Should we continue? */
    if (ppReturn != 0)
    {
       /* Check for a predefined binding. */
-      if (checkCDKObjectBind (vSELECTION, selection, input) != 0)
+      if (checkCDKObjectBind (vSELECTION, widget, input) != 0)
       {
-	 checkEarlyExit(selection);
+	 checkEarlyExit (widget);
 	 complete = TRUE;
       }
       else
       {
 	 switch (input)
 	 {
-	    case KEY_UP :
-		 scroller_KEY_UP(selection);
-		 break;
+	 case KEY_UP:
+	    scroller_KEY_UP (widget);
+	    break;
 
-	    case KEY_DOWN :
-		 scroller_KEY_DOWN(selection);
-		 break;
+	 case KEY_DOWN:
+	    scroller_KEY_DOWN (widget);
+	    break;
 
-	    case KEY_RIGHT :
-		 scroller_KEY_RIGHT(selection);
-		 break;
+	 case KEY_RIGHT:
+	    scroller_KEY_RIGHT (widget);
+	    break;
 
-	    case KEY_LEFT :
-		 scroller_KEY_LEFT(selection);
-		 break;
+	 case KEY_LEFT:
+	    scroller_KEY_LEFT (widget);
+	    break;
 
-	    case KEY_PPAGE :
-		 scroller_KEY_PPAGE(selection);
-		 break;
+	 case KEY_PPAGE:
+	    scroller_KEY_PPAGE (widget);
+	    break;
 
-	    case KEY_NPAGE :
-		 scroller_KEY_NPAGE(selection);
-		 break;
+	 case KEY_NPAGE:
+	    scroller_KEY_NPAGE (widget);
+	    break;
 
-	    case KEY_HOME :
-		 scroller_KEY_HOME(selection);
-		 break;
+	 case KEY_HOME:
+	    scroller_KEY_HOME (widget);
+	    break;
 
-	    case KEY_END :
-		 scroller_KEY_END(selection);
-		 break;
+	 case KEY_END:
+	    scroller_KEY_END (widget);
+	    break;
 
-	    case '$' :
-		 selection->leftChar = selection->maxLeftChar;
-		 break;
+	 case '$':
+	    widget->leftChar = widget->maxLeftChar;
+	    break;
 
-	    case '|' :
-		 selection->leftChar = 0;
-		 break;
+	 case '|':
+	    widget->leftChar = 0;
+	    break;
 
-	    case SPACE :
-		 if (selection->mode[selection->currentItem] == 0)
-		 {
-		    if (selection->selections[selection->currentItem] == selection->choiceCount - 1)
-		    {
-		       selection->selections[selection->currentItem] = 0;
-		    }
-		    else
-		    {
-		       selection->selections[selection->currentItem]++;
-		    }
-		 }
-		 else
-		 {
-		    Beep();
-		 }
-		 break;
+	 case SPACE:
+	    if (selection->mode[widget->currentItem] == 0)
+	    {
+	       if (selection->selections[widget->currentItem]
+		   == (selection->choiceCount - 1))
+	       {
+		  selection->selections[widget->currentItem] = 0;
+	       }
+	       else
+	       {
+		  selection->selections[widget->currentItem]++;
+	       }
+	    }
+	    else
+	    {
+	       Beep ();
+	    }
+	    break;
 
-	    case KEY_ESC :
-		 setExitType(selection, input);
-		 complete = TRUE;
-		 break;
+	 case KEY_ESC:
+	    setExitType (widget, input);
+	    complete = TRUE;
+	    break;
 
-	    case KEY_TAB : case KEY_ENTER :
-		 setExitType(selection, input);
-		 ret = 1;
-		 complete = TRUE;
-		 break;
+	 case KEY_ERROR:
+	    setExitType (widget, input);
+	    complete = TRUE;
+	    break;
 
-	    case CDK_REFRESH :
-		 eraseCDKScreen (ScreenOf(selection));
-		 refreshCDKScreen (ScreenOf(selection));
-		 break;
+	 case KEY_TAB:
+	 case KEY_ENTER:
+	    setExitType (widget, input);
+	    ret = 1;
+	    complete = TRUE;
+	    break;
 
-	    default :
-		 break;
+	 case CDK_REFRESH:
+	    eraseCDKScreen (ScreenOf (widget));
+	    refreshCDKScreen (ScreenOf (widget));
+	    break;
+
+	 default:
+	    break;
 	 }
       }
 
       /* Should we call a post-process? */
-      if (!complete && (PostProcessFuncOf(selection) != 0))
+      if (!complete && (PostProcessFuncOf (widget) != 0))
       {
-	 PostProcessFuncOf(selection) (vSELECTION, selection, PostProcessDataOf(selection), input);
+	 PostProcessFuncOf (widget) (vSELECTION,
+				     widget,
+				     PostProcessDataOf (widget),
+				     input);
       }
    }
 
-   if (!complete) {
-      drawCDKSelectionList (selection, ObjOf(selection)->box);
-      setExitType(selection, 0);
+   if (!complete)
+   {
+      drawCDKSelectionList (selection, ObjOf (widget)->box);
+      setExitType (widget, 0);
    }
 
-   ResultOf(selection).valueInt = ret;
+   ResultOf (widget).valueInt = ret;
    fixCursorPosition (selection);
    return (ret != unknownInt);
 }
@@ -393,15 +429,20 @@ static int _injectCDKSelection (CDKOBJS *object, chtype input)
 /*
  * This moves the selection field to the given location.
  */
-static void _moveCDKSelection (CDKOBJS *object, int xplace, int yplace, boolean relative, boolean refresh_flag)
+static void _moveCDKSelection (CDKOBJS *object,
+			       int xplace,
+			       int yplace,
+			       boolean relative,
+			       boolean refresh_flag)
 {
    CDKSELECTION *selection = (CDKSELECTION *)object;
-   int currentX = getbegx(selection->win);
-   int currentY = getbegy(selection->win);
-   int xpos	= xplace;
-   int ypos	= yplace;
-   int xdiff	= 0;
-   int ydiff	= 0;
+   /* *INDENT-EQLS* */
+   int currentX = getbegx (selection->win);
+   int currentY = getbegy (selection->win);
+   int xpos     = xplace;
+   int ypos     = yplace;
+   int xdiff    = 0;
+   int ydiff    = 0;
 
    /*
     * If this is a relative move, then we will adjust where we want
@@ -409,29 +450,29 @@ static void _moveCDKSelection (CDKOBJS *object, int xplace, int yplace, boolean
     */
    if (relative)
    {
-      xpos = getbegx(selection->win) + xplace;
-      ypos = getbegy(selection->win) + yplace;
+      xpos = getbegx (selection->win) + xplace;
+      ypos = getbegy (selection->win) + yplace;
    }
 
    /* Adjust the window if we need to. */
-   alignxy (WindowOf(selection), &xpos, &ypos, selection->boxWidth, selection->boxHeight);
+   alignxy (WindowOf (selection), &xpos, &ypos, selection->boxWidth, selection->boxHeight);
 
    /* Get the difference. */
    xdiff = currentX - xpos;
    ydiff = currentY - ypos;
 
    /* Move the window to the new location. */
-   moveCursesWindow(selection->win, -xdiff, -ydiff);
-   moveCursesWindow(selection->scrollbarWin, -xdiff, -ydiff);
-   moveCursesWindow(selection->shadowWin, -xdiff, -ydiff);
+   moveCursesWindow (selection->win, -xdiff, -ydiff);
+   moveCursesWindow (selection->scrollbarWin, -xdiff, -ydiff);
+   moveCursesWindow (selection->shadowWin, -xdiff, -ydiff);
 
    /* Touch the windows so they 'move'. */
-   refreshCDKWindow (WindowOf(selection));
+   refreshCDKWindow (WindowOf (selection));
 
    /* Redraw the window, if they asked for it. */
    if (refresh_flag)
    {
-      drawCDKSelection (selection, ObjOf(selection)->box);
+      drawCDKSelection (selection, ObjOf (selection)->box);
    }
 }
 
@@ -454,17 +495,17 @@ static void _drawCDKSelection (CDKOBJS *object, boolean Box)
    drawCDKSelectionList (selection, Box);
 }
 
-static int maxViewSize(CDKSELECTION *widget)
+static int maxViewSize (CDKSELECTION *widget)
 {
-   return scroller_MaxViewSize(widget);
+   return scroller_MaxViewSize ((CDKSCROLLER *)widget);
 }
 
 /*
  * Set variables that depend upon the list-size.
  */
-static void setViewSize(CDKSELECTION *widget, int listSize)
+static void setViewSize (CDKSELECTION *widget, int listSize)
 {
-   scroller_SetViewSize(widget, listSize);
+   scroller_SetViewSize ((CDKSCROLLER *)widget, listSize);
 }
 
 /*
@@ -472,66 +513,75 @@ static void setViewSize(CDKSELECTION *widget, int listSize)
  */
 static void drawCDKSelectionList (CDKSELECTION *selection, boolean Box GCC_UNUSED)
 {
-   int scrollbarAdj	= (selection->scrollbarPlacement == LEFT) ? 1 : 0;
-   int screenPos	= 0;
+   /* *INDENT-EQLS* */
+   int scrollbarAdj     = (selection->scrollbarPlacement == LEFT) ? 1 : 0;
+   int screenPos        = 0;
    int xpos, ypos;
-   int j;
-   int selItem      = -1;
+   int j, k;
+   int selItem          = -1;
 
    /* If there is to be a highlight, assign it now */
-   if (ObjOf(selection)->hasFocus)
+   if (ObjOf (selection)->hasFocus)
       selItem = selection->currentItem;
 
    /* draw the list... */
    for (j = 0; j < selection->viewSize; j++)
    {
-      screenPos = SCREENPOS(selection, j + selection->currentTop);
-      ypos = SCREEN_YPOS(selection, j);
-      xpos = SCREEN_XPOS(selection, 0);
+      xpos = SCREEN_XPOS (selection, 0);
+      ypos = SCREEN_YPOS (selection, j);
 
       /* Draw the empty line. */
-      writeBlanks (selection->win,
-		   xpos,
-		   ypos,
-		   HORIZONTAL, 0,
-		   getmaxx(selection->win));
+      writeBlanks (selection->win, xpos, ypos,
+		   HORIZONTAL, 0, getmaxx (selection->win));
 
-      /* Draw the selection item. */
-      writeChtypeAttrib (selection->win,
-		   (screenPos >= 0) ? screenPos : 1,
-		   ypos,
-		   selection->item[j + selection->currentTop],
-		   ((j + selection->currentTop == selItem)
-		     ? selection->highlight
-		     : A_NORMAL),
-		   HORIZONTAL,
-		   (screenPos >= 0) ? 0 : (1 - screenPos),
-		   selection->itemLen[j + selection->currentTop]);
+      k = j + selection->currentTop;
 
-      /* Draw the choice value. */
-      writeChtype (selection->win,
-		   xpos + scrollbarAdj,
-		   ypos,
-		   selection->choice[selection->selections[j + selection->currentTop]],
-		   HORIZONTAL,
-		   0,
-		   selection->choicelen[selection->selections[j + selection->currentTop]]);
+      /* Draw the element in the selection list. */
+      if (k < selection->listSize)
+      {
+	 screenPos = SCREENPOS (selection, k);
+
+	 /* Draw the selection item. */
+	 writeChtypeAttrib (selection->win,
+			    (screenPos >= 0) ? screenPos : 1,
+			    ypos,
+			    selection->item[k],
+			    ((k == selItem)
+			     ? selection->highlight
+			     : A_NORMAL),
+			    HORIZONTAL,
+			    (screenPos >= 0) ? 0 : (1 - screenPos),
+			    selection->itemLen[k]);
+
+	 /* Draw the choice value. */
+	 writeChtype (selection->win,
+		      xpos + scrollbarAdj,
+		      ypos,
+		      selection->choice[selection->selections[k]],
+		      HORIZONTAL,
+		      0,
+		      selection->choicelen[selection->selections[k]]);
+      }
    }
 
    /* Determine where the toggle is supposed to be. */
    if (selection->scrollbar)
    {
-      selection->togglePos = floorCDK(selection->currentItem * selection->step);
-      selection->togglePos = MINIMUM(selection->togglePos, getmaxy(selection->scrollbarWin) - 1);
+      selection->togglePos = floorCDK (selection->currentItem * (double)selection->step);
+      selection->togglePos = MINIMUM (selection->togglePos,
+				      (getmaxy (selection->scrollbarWin) - 1));
 
-      mvwvline (selection->scrollbarWin, 0, 0, ACS_CKBOARD, getmaxy(selection->scrollbarWin));
-      mvwvline (selection->scrollbarWin, selection->togglePos, 0, ' ' | A_REVERSE, selection->toggleSize);
+      (void)mvwvline (selection->scrollbarWin, 0, 0, ACS_CKBOARD, getmaxy (selection->scrollbarWin));
+      (void)mvwvline (selection->scrollbarWin,
+		      selection->togglePos,
+		      0,
+		      ' ' | A_REVERSE, selection->toggleSize);
    }
 
    /* Box it if needed */
-   if (ObjOf(selection)->box)
+   if (ObjOf (selection)->box)
    {
-      drawObjBox (selection->win, ObjOf(selection));
+      drawObjBox (selection->win, ObjOf (selection));
    }
 
    fixCursorPosition (selection);
@@ -544,7 +594,7 @@ static void _setBKattrSelection (CDKOBJS *object, chtype attrib)
 {
    if (object != 0)
    {
-      CDKSELECTION *widget = (CDKSELECTION *) object;
+      CDKSELECTION *widget = (CDKSELECTION *)object;
 
       wbkgd (widget->win, attrib);
       if (widget->scrollbarWin != 0)
@@ -609,38 +659,41 @@ static void _eraseCDKSelection (CDKOBJS *object)
 /*
  * This function sets a couple of the selection list attributes.
  */
-void setCDKSelection (CDKSELECTION *selection, chtype highlight, int * choices, boolean Box)
+void setCDKSelection (CDKSELECTION *selection,
+		      chtype highlight,
+		      int *choices,
+		      boolean Box)
 {
    setCDKSelectionChoices (selection, choices);
-   setCDKSelectionHighlight(selection, highlight);
+   setCDKSelectionHighlight (selection, highlight);
    setCDKSelectionBox (selection, Box);
 }
 
 /*
  * This sets the selection list items.
  */
-void setCDKSelectionItems (CDKSELECTION *selection, char **list, int listSize)
+void setCDKSelectionItems (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 {
-   int widestItem	= -1;
-   int j		= 0;
+   int widestItem = -1;
+   int j = 0;
 
-   widestItem = createList(selection, list, listSize);
+   widestItem = createList (selection, list, listSize);
    if (widestItem <= 0)
       return;
 
    /* Clean up the display. */
-   for (j = 0; j < selection->viewSize ; j++)
+   for (j = 0; j < selection->viewSize; j++)
    {
       writeBlanks (selection->win,
-		   SCREEN_XPOS(selection, 0),
-		   SCREEN_YPOS(selection, j),
-		   HORIZONTAL, 0, getmaxx(selection->win));
+		   SCREEN_XPOS (selection, 0),
+		   SCREEN_YPOS (selection, j),
+		   HORIZONTAL, 0, getmaxx (selection->win));
    }
 
-   setViewSize(selection, listSize);
+   setViewSize (selection, listSize);
    setCDKSelectionCurrent (selection, 0);
 
-   updateViewWidth(selection, widestItem);
+   updateViewWidth (selection, widestItem);
 }
 int getCDKSelectionItems (CDKSELECTION *selection, char **list)
 {
@@ -659,7 +712,7 @@ int getCDKSelectionItems (CDKSELECTION *selection, char **list)
 /*
  *
  */
-void setCDKSelectionTitle (CDKSELECTION *selection, char *title)
+void setCDKSelectionTitle (CDKSELECTION *selection, const char *title)
 {
    /* Make sure the title isn't null. */
    if (title == 0)
@@ -667,13 +720,13 @@ void setCDKSelectionTitle (CDKSELECTION *selection, char *title)
       return;
    }
 
-   (void) setCdkTitle(ObjOf(selection), title, - (selection->boxWidth + 1));
+   (void)setCdkTitle (ObjOf (selection), title, -(selection->boxWidth + 1));
 
-   setViewSize(selection, selection->listSize);
+   setViewSize (selection, selection->listSize);
 }
 char *getCDKSelectionTitle (CDKSELECTION *selection GCC_UNUSED)
 {
-   return chtype2Char(*TitleOf(selection));
+   return chtype2Char (*TitleOf (selection));
 }
 
 /*
@@ -691,7 +744,7 @@ chtype getCDKSelectionHighlight (CDKSELECTION *selection)
 /*
  * This sets the default choices for the selection list.
  */
-void setCDKSelectionChoices (CDKSELECTION *selection, int * choices)
+void setCDKSelectionChoices (CDKSELECTION *selection, int *choices)
 {
    int j;
 
@@ -736,13 +789,13 @@ void setCDKSelectionChoice (CDKSELECTION *selection, int Index, int choice)
    }
 
    /* Make sure the index isn't out of range. */
-   if (Index < 0)
+   if (correctIndex < 0)
    {
-      Index = 0;
+      correctIndex = 0;
    }
-   else if (Index > selection->listSize)
+   else if (correctIndex > selection->listSize)
    {
-      Index = selection->listSize - 1;
+      correctIndex = selection->listSize - 1;
    }
 
    /* Set the choice value. */
@@ -769,7 +822,7 @@ int getCDKSelectionChoice (CDKSELECTION *selection, int Index)
  * This sets the modes of the items in the selection list. Currently
  * there are only two: editable=0 and read-only=1
  */
-void setCDKSelectionModes (CDKSELECTION *selection, int * modes)
+void setCDKSelectionModes (CDKSELECTION *selection, int *modes)
 {
    int j;
 
@@ -837,12 +890,12 @@ int getCDKSelectionMode (CDKSELECTION *selection, int Index)
  */
 void setCDKSelectionBox (CDKSELECTION *selection, boolean Box)
 {
-   ObjOf(selection)->box = Box;
-   ObjOf(selection)->borderSize = Box ? 1 : 0;
+   ObjOf (selection)->box = Box;
+   ObjOf (selection)->borderSize = Box ? 1 : 0;
 }
 boolean getCDKSelectionBox (CDKSELECTION *selection)
 {
-   return ObjOf(selection)->box;
+   return ObjOf (selection)->box;
 }
 
 /*
@@ -850,7 +903,7 @@ boolean getCDKSelectionBox (CDKSELECTION *selection)
  */
 void setCDKSelectionCurrent (CDKSELECTION *selection, int item)
 {
-   scroller_SetPosition(selection, item);
+   scroller_SetPosition ((CDKSCROLLER *)selection, item);
 }
 
 int getCDKSelectionCurrent (CDKSELECTION *selection)
@@ -861,42 +914,43 @@ int getCDKSelectionCurrent (CDKSELECTION *selection)
 /*
  * methods for generic type methods
  */
-static void _focusCDKSelection(CDKOBJS *object)
+static void _focusCDKSelection (CDKOBJS *object)
 {
    CDKSELECTION *selection = (CDKSELECTION *)object;
 
-   drawCDKSelectionList (selection, ObjOf(selection)->box);
+   drawCDKSelectionList (selection, ObjOf (selection)->box);
 }
 
-static void _unfocusCDKSelection(CDKOBJS *object)
+static void _unfocusCDKSelection (CDKOBJS *object)
 {
    CDKSELECTION *selection = (CDKSELECTION *)object;
 
-   drawCDKSelectionList (selection, ObjOf(selection)->box);
+   drawCDKSelectionList (selection, ObjOf (selection)->box);
 }
 
-static int createList(CDKSELECTION *selection, char **list, int listSize)
+static int createList (CDKSELECTION *selection, CDK_CSTRING2 list, int listSize)
 {
    int status = 0;
    int widestItem = 0;
    int j;
 
-   if (listSize > 0)
+   if (listSize >= 0)
    {
-      chtype **	newList = typeCallocN(chtype *, listSize + 1);
-      int *	newLen  = typeCallocN(int, listSize + 1);
-      int *	newPos  = typeCallocN(int, listSize + 1);
-      int *	newSel  = typeCallocN(int, listSize + 1);
-      int *	newMode = typeCallocN(int, listSize + 1);
+      /* *INDENT-EQLS* */
+      chtype **newList  = typeCallocN (chtype *, listSize + 1);
+      int *newLen       = typeCallocN (int, listSize + 1);
+      int *newPos       = typeCallocN (int, listSize + 1);
+      int *newSel       = typeCallocN (int, listSize + 1);
+      int *newMode      = typeCallocN (int, listSize + 1);
 
       if (newList != 0
-       && newLen != 0
-       && newPos != 0
-       && newSel != 0
-       && newMode != 0)
+	  && newLen != 0
+	  && newPos != 0
+	  && newSel != 0
+	  && newMode != 0)
       {
-	 int boxWidth = AvailableWidth(selection);
-	 int adjust = selection->maxchoicelen + BorderOf(selection);
+	 int boxWidth = AvailableWidth (selection);
+	 int adjust = selection->maxchoicelen + BorderOf (selection);
 
 	 status = 1;
 	 for (j = 0; j < listSize; j++)
@@ -907,7 +961,7 @@ static int createList(CDKSELECTION *selection, char **list, int listSize)
 	       status = 0;
 	       break;
 	    }
-	    newPos[j]  = justifyString (boxWidth, newLen[j], newPos[j]) + adjust;
+	    newPos[j] = justifyString (boxWidth, newLen[j], newPos[j]) + adjust;
 	    widestItem = MAXIMUM (widestItem, newLen[j]);
 	 }
 
@@ -915,11 +969,12 @@ static int createList(CDKSELECTION *selection, char **list, int listSize)
 	 {
 	    destroyInfo (selection);
 
-	    selection->item	  = newList;
-	    selection->itemPos	  = newPos;
-	    selection->itemLen	  = newLen;
+	    /* *INDENT-EQLS* */
+	    selection->item      = newList;
+	    selection->itemPos   = newPos;
+	    selection->itemLen   = newLen;
 	    selection->selections = newSel;
-	    selection->mode	  = newMode;
+	    selection->mode      = newMode;
 	 }
 	 else
 	 {
@@ -930,6 +985,14 @@ static int createList(CDKSELECTION *selection, char **list, int listSize)
 	    freeChecked (newMode);
 	 }
       }
+      else
+      {
+	 CDKfreeChtypes (newList);
+	 freeChecked (newPos);
+	 freeChecked (newLen);
+	 freeChecked (newSel);
+	 freeChecked (newMode);
+      }
    }
    else
    {
@@ -939,6 +1002,6 @@ static int createList(CDKSELECTION *selection, char **list, int listSize)
    return status ? widestItem : 0;
 }
 
-dummyRefreshData(Selection)
+dummyRefreshData (Selection)
 
-dummySaveData(Selection)
+dummySaveData (Selection)
